marktools.attach_lilypond_comments_to_components_in_expr
========================================================

.. autofunction:: abjad.tools.marktools.attach_lilypond_comments_to_components_in_expr.attach_lilypond_comments_to_components_in_expr
